package it.unibo.lbedogni.datamanagement;

import android.content.ContentValues;
import android.content.Context;
import android.database.Cursor;
import android.database.sqlite.SQLiteDatabase;
import android.database.sqlite.SQLiteOpenHelper;
import android.util.Log;

public class DBHelper extends SQLiteOpenHelper {

	public static final String TABLE_GRADES = "grades";
	public static final String COLUMN_ID = "_id";
	public static final String COLUMN_FIRST_NAME = "firstName";
	public static final String COLUMN_LAST_NAME = "secondName";
	public static final String COLUMN_CLASS = "class";
	public static final String COLUMN_GRADE = "grade";
	
	private static final String DATABASE_NAME = "grades.db";
	private static final int DATABASE_VERSION = 1;

	// Database creation sql statement
	private static final String DATABASE_CREATE = "create table "
			+ TABLE_GRADES + "( " + COLUMN_ID + " integer primary key autoincrement, "
			+ COLUMN_FIRST_NAME	+ " text not null, "
			+ COLUMN_LAST_NAME + " text not null, "
			+ COLUMN_CLASS + " text not null, "
			+ COLUMN_GRADE + " integer not null);";

	public DBHelper(Context context) {
		super(context, DATABASE_NAME, null, DATABASE_VERSION);
	}

	@Override
	public void onCreate(SQLiteDatabase database) {
		database.execSQL(DATABASE_CREATE);
	}

	@Override
	public void onUpgrade(SQLiteDatabase db, int oldVersion, int newVersion) {
		Log.w(DBHelper.class.getName(),
				"Upgrading database from version " + oldVersion + " to "
						+ newVersion + ", which will destroy all old data");
		db.execSQL("DROP TABLE IF EXISTS " + TABLE_GRADES);
		onCreate(db);
	}
	
	public long insertNewStudent(String firstName, String lastName, String className, int grade) {
		ContentValues cv = new ContentValues();
		cv.put(COLUMN_FIRST_NAME, firstName);
		cv.put(COLUMN_LAST_NAME, lastName);
		cv.put(COLUMN_CLASS, className);
		cv.put(COLUMN_GRADE, grade);
		
		long code = getWritableDatabase().insert(TABLE_GRADES, null, cv);
		return code;
	}
	
	public Cursor getGrades() {
		return getWritableDatabase().query(TABLE_GRADES, null, null, null, null, null, null);
	}
	
	public void deleteStudent(int id) {
		getWritableDatabase().delete(TABLE_GRADES, COLUMN_ID + "=?", new String[] { String.valueOf(id) });
	}
	
	public Cursor get30() {
		return getWritableDatabase().query(TABLE_GRADES, null, COLUMN_GRADE + "=?", new String[] { "30" }, null, null, null);
	}
}