package it.unibo.lbedogni.datamanagement;

import android.content.Context;
import android.content.Intent;
import android.os.Bundle;
import android.os.Environment;
import android.support.v7.app.AppCompatActivity;
import android.util.Log;
import android.view.View;
import android.widget.Button;
import android.widget.TextView;

import java.io.File;
import java.io.FileOutputStream;
import java.io.IOException;
import java.io.InputStream;

public class MainActivity extends AppCompatActivity implements View.OnClickListener {

    Button btnSharedPreferences;
    Button btnPreferenceScreen;
    Button btnCreateFiles;
    Button btnRaw;
    Button btnXml;
    Button btnDatabase;
    Button btnContentProvider;
    Button btnRoomDatabase;

    TextView tvRaw;

    @Override
    protected void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        setContentView(R.layout.activity_main);

        btnSharedPreferences = (Button)findViewById(R.id.btnSharedPreferences);
        btnPreferenceScreen = (Button)findViewById(R.id.btnPreferenceScreen);
        btnCreateFiles = (Button)findViewById(R.id.btnCreateFiles);
        btnRaw = (Button)findViewById(R.id.btnRawTextFile);
        btnXml = (Button)findViewById(R.id.btnXml);
        btnDatabase = (Button)findViewById(R.id.btnDatabase);
        btnContentProvider = (Button)findViewById(R.id.btnContentProvider);
        btnRoomDatabase = (Button)findViewById(R.id.btnRoomDatabase);

        tvRaw = (TextView)findViewById(R.id.tvRaw);

        btnSharedPreferences.setOnClickListener(this);
        btnPreferenceScreen.setOnClickListener(this);
        btnCreateFiles.setOnClickListener(this);
        btnRaw.setOnClickListener(this);
        btnXml.setOnClickListener(this);
        btnDatabase.setOnClickListener(this);
        btnContentProvider.setOnClickListener(this);
        btnRoomDatabase.setOnClickListener(this);
    }

    @Override
    public void onClick(View v) {
        if (v == btnSharedPreferences) {
            Intent i = new Intent(getApplicationContext(),mySharedPreferences.class);
            startActivity(i);
        } else if (v == btnPreferenceScreen) {
            Intent i = new Intent(getApplicationContext(),PreferenceScreenActivity.class);
            startActivity(i);
        } else if (v == btnCreateFiles) {
            writeFiles();
        } else if (v == btnRaw) {
            InputStream in_s = getResources().openRawResource(R.raw.myfile);
            try {
                byte[] b = new byte[in_s.available()];
                in_s.read(b);
                tvRaw.setText(new String(b));
            } catch (Exception e) {
                tvRaw.setText("Can't get the file.");
            }
        } else if (v == btnXml) {
            Intent i = new Intent(getApplicationContext(),XmlFilesActivity.class);
            startActivity(i);
        } else if (v == btnDatabase) {
            Intent i = new Intent(getApplicationContext(), DatabaseActivity.class);
            startActivity(i);
        } else if (v == btnContentProvider) {
            Intent i = new Intent(getApplicationContext(), ContentProviderActivity.class);
            startActivity(i);
        } else if (v == btnRoomDatabase) {
            Intent i = new Intent(getApplicationContext(), RoomDatabaseActivity.class);
            startActivity(i);
        }
    }

    public void writeFiles() {

        try {
            FileOutputStream outputStream = openFileOutput("internalFilename.txt", Context.MODE_PRIVATE);
            outputStream.write("Contents".getBytes());
            outputStream.close();
        } catch (Exception e) {
            e.printStackTrace();
        }

        Log.v("FILES_LOG","internal file written");

        try {
            File file = new File(getPrivateAlbumStorageDir(getApplicationContext(),"My album"), "/private_file");
            FileOutputStream fos = new FileOutputStream(file);
            fos.write("Contents".getBytes());
            fos.close();
        } catch (IOException e) { }

        try {
            File file = new File(getPublicAlbumStorageDir("My album"), "/public_file");
            FileOutputStream fos = new FileOutputStream(file);
            fos.write("Contents".getBytes());
            fos.close();
        } catch (IOException e) { }
    }

    public File getPrivateAlbumStorageDir(Context context, String albumName) {
        File file = new File(context.getExternalFilesDir(
                Environment.DIRECTORY_PICTURES), albumName);
        if (!file.mkdirs()) {
            Log.e("FILES_LOG", "Directory not created");
        }
        return file;
    }

    public File getPublicAlbumStorageDir(String albumName) {
        File file = new File(Environment.getExternalStoragePublicDirectory(
                Environment.DIRECTORY_PICTURES), albumName);
        if (!file.mkdirs()) {
            Log.e("FILES_LOG", "Directory not created");
        }
        return file;
    }

    /* Checks if external storage is available for read and write */
    public boolean isExternalStorageWritable() {
        String state = Environment.getExternalStorageState();
        if (Environment.MEDIA_MOUNTED.equals(state)) {
            return true;
        }
        return false;
    }

    /* Checks if external storage is available to at least read */
    public boolean isExternalStorageReadable() {
        String state = Environment.getExternalStorageState();
        if (Environment.MEDIA_MOUNTED.equals(state) ||
                Environment.MEDIA_MOUNTED_READ_ONLY.equals(state)) {
            return true;
        }
        return false;
    }
}
